@@ -34,10 +34,13 @@
 Base ROS python library for manipulating ROS packages and stacks.
 """
 
+__version__ = '0.2.5'
+
 from .common import MANIFEST_FILE, STACK_FILE, ResourceNotFound
 from .environment import get_ros_root, get_ros_package_path, get_ros_home, \
      get_log_dir, get_test_results_dir, on_ros_path
 from .manifest import parse_manifest_file, Manifest, InvalidManifest
 from .rospack import RosPack, RosStack, \
-     list_by_path, expand_to_packages, get_stack_version_by_dir
+     list_by_path, expand_to_packages, get_stack_version_by_dir, \
+     get_package_name
 
